@@ -1,10 +1,12 @@
+from typing import Dict
+
 from pyspark.sql import SparkSession, Column, DataFrame
 from pyspark.sql.functions import array
 # noinspection PyUnresolvedReferences
 from pyspark.sql.functions import lit
 
-from spark_auto_mapper.automapper import AutoMapper
-from spark_auto_mapper.automapper_helpers import AutoMapperHelpers as A
+from spark_auto_mapper.automappers.automapper import AutoMapper
+from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
 def test_auto_mapper_array_multiple_items(spark_session: SparkSession):
@@ -28,8 +30,7 @@ def test_auto_mapper_array_multiple_items(spark_session: SparkSession):
         source_view="patients",
         keys=["member_id"]
     ).withColumn(
-        dst_column="dst2",
-        value=A.list(
+        dst2=A.list(
             [
                 "address1",
                 "address2"
@@ -37,10 +38,12 @@ def test_auto_mapper_array_multiple_items(spark_session: SparkSession):
         )
     )
 
-    sql_expression: Column = mapper.get_column_spec()
-    print(sql_expression)
+    assert isinstance(mapper, AutoMapper)
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs()
+    for column_name, sql_expression in sql_expressions.items():
+        print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expression) == str(array(lit("address1"), lit("address2")).alias("dst2"))
+    assert str(sql_expressions["dst2"]) == str(array(lit("address1"), lit("address2")).alias("dst2"))
 
     result_df: DataFrame = mapper.transform(df=df)
 
